@@ -1301,6 +1301,14 @@ class ModuleGeneratorTest(EnhancedTestCase):
                                        ['Compiler/intel/2019.4.243'], ['Core']),
             'imkl-2019.4.243-iimpi-2019.08.eb': ('imkl/2019.4.243',
                                                  'MPI/intel/2019.4.243/impi/2019.4.243', [], [], ['Core']),
+            'intel-compilers-2021.2.0.eb': ('intel-compilers/2021.2.0', 'Core',
+                                            ['Compiler/intel/2021.2.0'], ['Compiler/intel/2021.2.0'], ['Core']),
+            'impi-2021.2.0-intel-compilers-2021.2.0.eb': ('impi/2021.2.0', 'Compiler/intel/2021.2.0',
+                                                          ['MPI/intel/2021.2.0/impi/2021.2.0'],
+                                                          ['MPI/intel/2021.2.0/impi/2021.2.0'],
+                                                          ['Core']),
+            'imkl-2021.2.0-iimpi-2021a.eb': ('imkl/2021.2.0', 'MPI/intel/2021.2.0/impi/2021.2.0',
+                                             [], [], ['Core']),
             'CUDA-9.1.85-GCC-6.4.0-2.28.eb': ('CUDA/9.1.85', 'Compiler/GCC/6.4.0-2.28',
                                               ['Compiler/GCC-CUDA/6.4.0-2.28-9.1.85'],
                                               ['Compiler/GCC-CUDA/6.4.0-2.28-9.1.85'], ['Core']),
